@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12870 2021-04-29 11:05:43Z Lavender $
+# $Id: __init__.py 12973 2021-06-13 11:56:03Z Becca $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2021-04-29 19:05:43 +0800 (Thu, 29 Apr 2021) $
-# $Revision: 12870 $
+# $Author: Becca $ (last)
+# $Date: 2021-06-13 19:56:03 +0800 (Sun, 13 Jun 2021) $
+# $Revision: 12973 $
 
 from __future__ import print_function
 
@@ -982,6 +982,36 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                 raise KeyError(
                     "You should set DEVELOPMENT, STAGE, "
                     "PRODUCTION in IUNO_SITE_DOMAIN_NAMES")
+    #=========================================================================
+
+    #=========================================================================
+    # debug tool bar
+    try:
+        import debug_toolbar
+    except ImportError:
+        warnings.warn(
+            colored(
+                "Can't import debug_toolbar."
+                " Please install django-debug-toolbar==1.9.1.",
+                'yellow', attrs=['bold']
+            )
+        )
+    else:
+        if settingsDict.get('DEBUG_TOOLBAR_ENABLE', None):
+            extendInstalledApps(settingsDict, ('debug_toolbar',))
+            extendMiddlewareClasses(
+                settingsDict,
+                ("debug_toolbar.middleware.DebugToolbarMiddleware",)
+            )
+
+            toolbarSettings = {
+                'INTERNAL_IPS': ['127.0.0.1'],
+            }
+            update(settingsDict, toolbarSettings)
+
+            populateEnvToSettings((
+                'INTERNAL_IPS',
+            ), settingsDict)
 
 
 # detect Server mode
@@ -1031,16 +1061,6 @@ def attachDebugURLs(settings, urlpatterns):
     """
     from django.conf.urls import url, include
 
-    try:
-        import debug_toolbar
-    except:
-        pass
-    else:
-        if settings.DEBUG:
-            urlpatterns += patterns('',
-                url(r'^__debug__/', include(debug_toolbar.urls)),
-            )
-
 def attachURLs(settings, urlpatterns, excludeApps=()):
     """
     Attach patched (for example, debug and admin...etc.) urlpatterns.
@@ -1051,12 +1071,23 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
     """
 
     from django.conf.urls import url, include
+    from django.urls import path, include
     from des import urls as des_urls
 
     urlpatterns += patterns('',
         url(r'^django-des/', include(des_urls)),
     )
 
+    try:
+        import debug_toolbar
+    except:
+        pass
+    else:
+        if settings.DEBUG:
+            urlpatterns += patterns('',
+                path(r'^__debug__/', include(debug_toolbar.urls)),
+            )
+
     #==========================================================================
     # Iuno.member.
     if not "Iuno.member" in excludeApps:
